@@ -4,6 +4,7 @@
 #include <QtGui>
 
 class WrPlugin;
+class HtmlDelegate;
 
 namespace Ui {
     class ProviderWindow;
@@ -25,6 +26,7 @@ private:
     WrPlugin *plugin;
     QStandardItemModel *model;
     bool editMode;
+    HtmlDelegate *delegate;
 
 private slots:
     void on_actionEdit_mode_triggered();
